**django-markupmirror** is a custom field and widget for editing markup text
in Django. It utilizes the `CodeMirror`_ JS editor for a richer editing
experience.

It uses parts of `James Turk's`_ `django-markupfield`_ and adds a nicer widget
with live-preview and an extension content-type for `FeinCMS`_.

**Documentation**
    on Read the Docs: http://django-markupmirror.readthedocs.org/

**Code and issues**
    on bitbucket: https://bitbucket.org/fabianbuechler/django-markupmirror

**Releases**
    on PyPi: http://pypi.python.org/pypi/django-markupmirror

.. _CodeMirror: http://codemirror.net/
.. _James Turk's: https://github.com/jamesturk
.. _django-markupfield: https://github.com/jamesturk/django-markupfield
.. _FeinCMS: http://www.feinheit.ch/media/labs/feincms/
